==> code-saturne_5.2.1%2Brepack.orig.tar.gz: code-saturne-5.2.1.orig/docs/doxygen/examples/cs_user_tabs.h <==
/*============================================================================
 * Code_Saturne documentation page
 *============================================================================*/

/*
  This file is part of Code_Saturne, a general-purpose CFD tool.

  Copyright (C) 1998-2018 EDF S.A.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 2 of the License, or (at your option) any later
  version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
  Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/*----------------------------------------------------------------------------*/

/*!
  \page cs_user_examples User examples

Here is a list of user examples. Thoroughly documented snippets are provided.

\section example_preprocessing Preprocessing
   - \subpage cs_user_mesh "Preprocessing and mesh modification examples"
   - \subpage user_coupling

\section example_model_selection Model selection and global parameters setting
   - \subpage f_parameters
   - \subpage parameters
   - \subpage turbomachinery
   - \subpage cavit
   - \subpage cs_lagrangian_particle_tracking_module
   - \subpage cs_user_fluid_structure_interaction
   - \subpage richards
   - \subpage cs_user_gwf_cdo
   - \subpage cs_user_radiative_transfer
   - \subpage cs_user_electric_scaling
   - \subpage cs_user_atmospheric_model
   - \subpage cs_user_cooling_towers "Cooling towers definition"

\section example_physical_properties Physical properties definition
   - \subpage physical_properties
   - \subpage cs_porosity "Define porous modelling properties"
   - \subpage drift_coal_scalars
   - \subpage drift_scalars

\section example_volume_bc Volume and boundary conditions
   - \subpage user_initialization "Physical fields user initialization"
   - \subpage cs_user_boundary_conditions_examples "User boundary condition definitions"
   - \subpage cs_user_boundary_conditions_ale "User boundary condition definition for the ALE model"
   - \subpage les_inflow "Inflow Boundary conditions for LES"
   - \subpage cs_head_losses "Define head losses zones"
   - \subpage cs_user_source_terms "Define additional source terms for transport equations (momentum and species)"
   - \subpage cs_user_mass_source_terms "Define mass source termes"
   - \subpage condens "Define condensation"

\section example_numerical_param Numerical parameters
   - \subpage cs_user_performance_tuning

\section example_calculation_control Calculation control
   - \subpage cs_user_postprocess
   - \subpage cs_user_postprocess_var
   - \subpage cs_user_extra_operations_examples "User extra operations"
   - \subpage cs_user_extra_operations-nusselt_calculation

\section example_other OtherCalculation control
   - \subpage cs_user_modules
   - \subpage user_solver
   - \subpage us_thht
   - \subpage us_vosy
   - \subpage us_pt1d
   - \subpage us_vort

*/

==> code-saturne_5.3.2%2Brepack.orig.tar.gz: code-saturne-5.3.2.orig/docs/doxygen/examples/cs_user_tabs.h <==
/*============================================================================
 * Code_Saturne documentation page
 *============================================================================*/

/*
  This file is part of Code_Saturne, a general-purpose CFD tool.

  Copyright (C) 1998-2018 EDF S.A.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 2 of the License, or (at your option) any later
  version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
  Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/*----------------------------------------------------------------------------*/

/*!
  \page cs_user_examples User examples

Here is a list of user examples. Thoroughly documented snippets are provided.

\section example_preprocessing Preprocessing
   - \subpage cs_user_mesh "Preprocessing and mesh modification examples"
   - \subpage user_coupling

\section example_model_selection Model selection and global parameters setting
   - \subpage f_parameters
   - \subpage parameters
   - \subpage turbomachinery
   - \subpage cavit
   - \subpage cs_lagrangian_particle_tracking_module
   - \subpage cs_user_fluid_structure_interaction
   - \subpage richards
   - \subpage cs_user_gwf_cdo
   - \subpage cs_user_radiative_transfer
   - \subpage cs_user_electric_scaling
   - \subpage cs_user_atmospheric_model
   - \subpage cs_user_cooling_towers "Cooling towers definition"

\section example_physical_properties Physical properties definition
   - \subpage physical_properties
   - \subpage cs_porosity "Define porous modelling properties"
   - \subpage drift_coal_scalars
   - \subpage drift_scalars

\section example_volume_bc Volume and boundary conditions
   - \subpage user_initialization "Physical fields user initialization"
   - \subpage cs_user_boundary_conditions_examples "User boundary condition definitions"
   - \subpage cs_user_boundary_conditions_ale "User boundary condition definition for the ALE model"
   - \subpage les_inflow "Inflow Boundary conditions for LES"
   - \subpage cs_head_losses "Define head losses zones"
   - \subpage cs_user_source_terms "Define additional source terms for transport equations (momentum and species)"
   - \subpage cs_user_mass_source_terms "Define mass source termes"
   - \subpage condens "Define condensation"

\section example_numerical_param Numerical parameters
   - \subpage cs_user_performance_tuning

\section example_calculation_control Calculation control and postprocessing
   - \subpage cs_user_postprocess
   - \subpage cs_user_extra_operations_examples "User extra operations"
   - \subpage cs_user_extra_operations-nusselt_calculation

\section example_other Other Calculation control
   - \subpage cs_user_modules
   - \subpage user_solver
   - \subpage us_thht
   - \subpage us_vosy
   - \subpage us_pt1d
   - \subpage us_vort

*/
